@@ -1,6 +1,6 @@
 # pages.py
 #
-# Copyright 2020 Fabio
+# Copyright (C) 2020-2023 Fabio Comuni, et al.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,6 +37,10 @@ from .config import APP_NAME, APP_ID, APP_VERSION, FMT_DAY_LIST
 from . import models
 
 
+def _convert_markdown_links(text):
+    """converts markdown links to html hyperlinks"""
+    return re.sub("\[([^]]+?)\]\(([^)\s]+?)(?:\s.*?)?\)", r'<a href="\2">\1</a>', text)
+
 def _clean_markup(text):
     """remove unsupported markup from text to use in label"""
     text = text.replace("<p>", "").replace("</p>", "\n\n")
@@ -203,6 +207,8 @@ class ConferencePage(BasePage):
         LBL_PROPS = {
             'justify': Gtk.Justification.CENTER,
             'halign' : Gtk.Align.CENTER, 
+            'selectable' : True,
+            'track-visited-links' : False,
             'wrap' : False,
         }
 
@@ -373,7 +379,7 @@ class SearchEventsPage(EventsPage):
         self.searchbar = searchbar
         self.nomatch_placeholder = PlaceholderWidget(
             text = _("No matches found"),
-            icon_name = 'system-search'
+            icon_name = 'system-search-symbolic'
         )
         self.nomatch_placeholder.show_all()
         super().__init__()
@@ -403,8 +409,10 @@ class EventDetailPage(BasePage):
         self.obj = obj
 
         LBL_PROPS = {
-            'justify': Gtk.Justification.FILL,
+            'justify': Gtk.Justification.LEFT,
             'halign' : Gtk.Align.START,
+            'selectable' : True,
+            'track-visited-links' : False,
             'wrap' : True,
         }
 
@@ -481,12 +489,12 @@ class EventDetailPage(BasePage):
         # By now just filter out, but a more in-depth look should be taken
         if obj.abstract is not None and obj.abstract != "" and obj.abstract != "None":
             label = Gtk.Label(**LBL_PROPS)
-            label.set_markup(_clean_markup(obj.abstract))
+            label.set_markup(_clean_markup(_convert_markdown_links(obj.abstract)))
             box.pack_start(label, False, False, 16)
 
         if obj.description is not None and obj.description != "" and obj.description != "None":
             label = Gtk.Label(**LBL_PROPS)
-            label.set_markup(_clean_markup(obj.description))
+            label.set_markup(_clean_markup(_convert_markdown_links(obj.description)))
             box.pack_start(label, False, False, 16)
 
         ## links
@@ -565,7 +573,7 @@ class StarredPage(BaseListPage):
         self.empty_placeholder.show_all()
         self.nomatch_placeholder = PlaceholderWidget(
             text = _("No matches found"),
-            icon_name = 'system-search'
+            icon_name = 'system-search-symbolic'
         )
         self.nomatch_placeholder.show_all()
 
