@@ -1,6 +1,6 @@
 # pentabarf.py
 #
-# Copyright 2020 Fabio
+# Copyright (C) 2020-2023 Fabio Comuni, et al.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -72,8 +72,10 @@ def import_pentabarf(xmlstr:str, url:str):
         for eevent in eday.iter('event'):
             fulltextsearch = []
             eventid = eevent.attrib['id']
+
+            tstart = eevent.find('start').text.strip()[:5]
             start = _local_to_utc_to_unset(
-                datetime.datetime.strptime(date + " " + eevent.find('start').text, "%Y-%m-%d %H:%M")
+                datetime.datetime.strptime(date + " " + tstart, "%Y-%m-%d %H:%M")
             )
             end = eevent.find('duration').text.split(":")
             end = start + datetime.timedelta(hours=int(end[0]), minutes=int(end[1]))
