@@ -1,6 +1,6 @@
 # widgets.py
 #
-# Copyright 2020 Fabio
+# Copyright (C) 2020-2023 Fabio Comuni, et al.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -263,6 +263,8 @@ class LoadingWidget(Handy.Clamp):
         fetcher.connect("notify", lambda *args: pb.set_fraction(fetcher.props.fraction))
         button.connect("clicked", lambda *args: fetcher.cancel())
 
+        box.set_margin_start(12)
+        box.set_margin_end(12)
         box.pack_start(img, False, False, 16)
         box.pack_start(label, False, False, 8)
         box.pack_start(pb, False, False, 8)
