@@ -1,6 +1,6 @@
 # self.py
 #
-# Copyright 2020 Fabio
+# Copyright (C) 2020-2023 Fabio Comuni, et al.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -69,7 +69,6 @@ class StartView(pages.BaseListPage):
             search_button
             update_button
 
-
         box
             search
             column
@@ -94,7 +93,7 @@ class StartView(pages.BaseListPage):
 
         self.nomatch_placeholder = PlaceholderWidget(
             text = _("No matches found"),
-            icon_name = 'system-search'
+            icon_name = 'system-search-symbolic'
         )
         self.nomatch_placeholder.show_all()
 
@@ -799,9 +798,10 @@ class ConfyWindow(Gtk.ApplicationWindow):
             program_name=APP_NAME,
             logo_icon_name=APP_ID,
             version=APP_VERSION,
-            copyright="© 2020 Fabio Comuni",
+            copyright="© 2020-2023 Fabio Comuni, et al.",
             website="https://confy.kirgroup.net/",
             authors=["Fabio Comuni", "Evangelos Ribeiro Tzaras", "Sebastian Crane"],
+            translator_credits='Irénée Thirion, Luna Jernberg',
             comments=_("Conference schedules viewer"),
             license_type=Gtk.License.GPL_3_0
         ).show()
